Install with pip
================

NumLPA is available on the `Python Package Index <https://pypi.org/project/numlpa>`_.
The easiest way to install it is to run the following command:

.. code-block:: bash

   pip install numlpa


If you do not wish to edit the package, the installation is now complete.
You can skip to the examples of commands to execute.
